@@ -23,6 +23,30 @@ import session
 _moduleLogger = logging.getLogger(__name__)
 
 
+class LedWrapper(object):
+
+	def __init__(self):
+		self._ledHandler = None
+		self._init = False
+
+	def off(self):
+		self._lazy_init()
+		if self._ledHandler is not None:
+			self._ledHandler.off()
+
+	def _lazy_init(self):
+		if self._init:
+			return
+		self._init = True
+		try:
+			import led_handler
+			self._ledHandler = led_handler.LedHandler()
+		except Exception, e:
+			_moduleLogger.exception('Unable to initialize LED Handling: "%s"' % str(e))
+			self._ledHandler = None
+
+
+
 class Dialcentral(object):
 
 	_DATA_PATHS = [
@@ -37,6 +61,7 @@ class Dialcentral(object):
 		self._hiddenUnits = {}
 		self._clipboard = QtGui.QApplication.clipboard()
 		self._dataPath = None
+		self._ledHandler = LedWrapper()
 		self.notifyOnMissed = False
 		self.notifyOnVoicemail = False
 		self.notifyOnSms = False
@@ -106,10 +131,10 @@ class Dialcentral(object):
 		isFullscreen = False
 		tabIndex = 0
 		try:
-			blobs = (
+			blobs = [
 				config.get(constants.__pretty_app_name__, "bin_blob_%i" % i)
 				for i in xrange(len(self._mainWindow.get_default_credentials()))
-			)
+			]
 			isFullscreen = config.getboolean(constants.__pretty_app_name__, "fullscreen")
 			tabIndex = config.getint(constants.__pretty_app_name__, "tab")
 		except ConfigParser.NoOptionError, e:
@@ -217,6 +242,10 @@ class Dialcentral(object):
 	def alarmHandler(self):
 		return self._alarmHandler
 
+	@property
+	def ledHandler(self):
+		return self._ledHandler
+
 	def _walk_children(self):
 		if self._mainWindow is not None:
 			return (self._mainWindow, )
